@@ -13,11 +13,17 @@ ensemble
 exceptions
     Module including custom warnings and error clases used across
     imbalanced-learn.
+keras
+    Module which provides custom generator, layers for deep learning using
+    keras.
 metrics
     Module which provides metrics to quantified the classification performance
     with imbalanced dataset.
 over_sampling
     Module which provides methods to under-sample a dataset.
+tensorflow
+    Module which provides custom generator, layers for deep learning using
+    tensorflow.
 under-sampling
     Module which provides methods to over-sample a dataset.
 utils
@@ -25,20 +31,32 @@ utils
 pipeline
     Module which allowing to create pipeline with scikit-learn estimators.
 """
+from . import combine
+from . import ensemble
+from . import exceptions
+from . import keras
+from . import metrics
+from . import over_sampling
+from . import tensorflow
+from . import under_sampling
+from . import utils
+from . import pipeline
 
-from .version import _check_module_dependencies, __version__
+from .base import FunctionSampler
+from ._version import __version__
+from .utils._show_versions import show_versions
 
-_check_module_dependencies()
-
-# Boolean controlling whether the joblib caches should be
-# flushed if the version of certain modules changes (eg nibabel, as it
-# does not respect the backward compatibility in some of its internal
-# structures
-# This  is used in nilearn._utils.cache_mixin
-CHECK_CACHE_VERSION = True
-
-# list all submodules available in imblearn and version
 __all__ = [
-    'combine', 'ensemble', 'exceptions', 'metrics', 'over_sampling',
-    'under_sampling', 'utils', 'pipeline', '__version__'
+    "combine",
+    "ensemble",
+    "exceptions",
+    "keras",
+    "metrics",
+    "over_sampling",
+    "tensorflow",
+    "under_sampling",
+    "utils",
+    "pipeline",
+    "FunctionSampler",
+    "__version__",
 ]
